global input_alpha

%% Calculating estimates

% IV regressions
% rho_y_x and eta_y_x are the linear IV coefficient and residual
% std_y_x is the IV standard error where we leave z implicit for simplicity

x_tilde=zeros(num_valid_obs,length_x);
z_tilde=zeros(num_valid_obs,length_x);

if iv_outcome==7 || iv_outcome==10 || iv_outcome==15 || iv_outcome==16 % IV regression
    for xcount=1:length_x
        x_tilde(:,xcount)=x(:,xcount)-mean(x(:,xcount));
        z_tilde(:,xcount)=z(:,xcount)-mean(z(:,xcount));
    end
    y_tilde= y-mean(y);
    rho_y_x_tilde= iv_regression(y_tilde, x_tilde, z_tilde);
    eta_y_x_tilde=  y_tilde-x_tilde*rho_y_x_tilde';
    std_y_x_tilde=  iv_get_std_error(x_tilde,z_tilde, eta_y_x_tilde, length_x);
    
else % when iv_outcome is 8, 9, 11, 12
    for xcount=1:length_x
        x_tilde(:,xcount)=x(:,xcount)-mean(x(:,xcount));
        z_tilde(:,xcount)=z(:,xcount)-mean(z(:,xcount));
    end
    y_tilde= y-mean(y);
	w_tilde= w-mean(w);
    
    rho_y_x_tilde= iv_regression(y_tilde, x_tilde, z_tilde);
    eta_y_x_tilde= y_tilde-x_tilde*rho_y_x_tilde';
    std_y_x_tilde= iv_get_std_error(x_tilde,z_tilde,eta_y_x_tilde, length_x);
    
    rho_w_x_tilde= iv_regression(w_tilde, x_tilde, z_tilde);
    eta_w_x_tilde= w_tilde-x_tilde*rho_w_x_tilde';
    std_w_x_tilde= iv_get_std_error(x_tilde,z_tilde,eta_w_x_tilde, length_x);
     
%%     Covariance matrix
    newvar=z_tilde.*repmat(eta_y_x_tilde, 1, length_x);
    newvar=[newvar z_tilde.*repmat(eta_w_x_tilde, 1, length_x)];
    Xi=cov(newvar, 1);

    Q=[z_tilde'*x_tilde/num_valid_obs zeros(length_x,length_x); zeros(length_x,length_x) z_tilde'*x_tilde/num_valid_obs];  
    Gamma=inv(Q)*Xi*inv(Q');
    
%% Computing bound estimates and confidence regions
    % Specify the function and gradient
    betaestfunc=@(d) rho_y_x_tilde-d*rho_w_x_tilde;
    Gfunc=@(d) [eye(length_x) -d*eye(length_x)];

% Obtain bound estimate and confidence regions
    tempest=setBoundsd(betaestfunc, Gfunc, 0, Gamma, num_valid_obs, length_x, 3);
    tempestmag=setBoundsd(betaestfunc, Gfunc, -1, Gamma, num_valid_obs, length_x, 3);
end

%% Printing Results

fprintf(1,'Number of Observations: %d\n',num_valid_obs);

for betacount=1:length_x
    generate_iv_xlabels;
    if iv_outcome==7 || iv_outcome==10 || iv_outcome==15 || iv_outcome==16
        stderror=std_y_x_tilde(betacount);
        
        c_alpha=norminv(1-(input_alpha/2),0,1);
        lower_ci=rho_y_x_tilde(betacount)-c_alpha*stderror;
        upper_ci=rho_y_x_tilde(betacount)+c_alpha*stderror;
        
        fprintf(1,'%s: R_y_x|z: %d | Std error: %d | CI: [%d %d]\n', xlabel, rho_y_x_tilde(betacount), stderror,lower_ci,upper_ci );
        
    else % iv_outcome is 8, 9, 11 or 12
        
        stderror=std_y_x_tilde(betacount);
        
        c_alpha=norminv(1-(input_alpha/2),0,1);
        lower_ci=rho_y_x_tilde(betacount)-c_alpha*stderror;
        upper_ci=rho_y_x_tilde(betacount)+c_alpha*stderror;
        
        fprintf(1,'%s: R_y_x|z: %d | Std error: %d | CI: [%d %d]\n', xlabel, rho_y_x_tilde(betacount), stderror,lower_ci,upper_ci );
        
        tstatvalue=rho_w_x_tilde(betacount)/std_w_x_tilde(betacount);
        pvalue=2*(1-normcdf(abs(tstatvalue))); %% two sided p-value
        fprintf(1,'R_w_x: %d | std error: %d | p-value: %d\n',rho_w_x_tilde(betacount),std_w_x_tilde(betacount),pvalue);
        
%% Reporting set estimates and confidence regions
        fprintf(1,'Identified region sign and mag: [%d %d]\n',tempest(betacount,[1 3]));
        fprintf(1,'CI:[%d %d]\n', tempest(betacount,[5 6]));
        fprintf(1,'Identified region mag: [%d %d]\n',tempestmag(betacount,[1 3]));
        fprintf(1,'CI:[%d %d]\n\n', tempestmag(betacount,[5 6]));
        
    end
end