clear all;
clc;

%% Specify the significance level
global input_alpha
input_alpha = input('Which significance level do you want to use (alpha)? [default=0.05] ');
if isempty(input_alpha)
    input_alpha = 0.05;
end;

length_raw_x= 20; % number of raw x
num_raw_obs=3010; % number of raw observations

%% retrive data from CSV file and populate the following variables
% data.csv: -1 means that particular data is missing
% data.csv has data in the following order
% 1. id | 2. nearc2 | 3. nearc4 | 4. educ | 5. age 
% | 6. fatheduc | 7. motheduc | 8. weight | 9. momdad14 | 10. sinmom14 
% | 11. step14 | 12. reg661 | 13. reg662 | 14. reg663 | 15. reg664 
%| 16. reg665 | 17 reg666 | 18. reg667 | 19. reg668 | 20. reg669 
% | 21. south66 | 22. black | 23. smsa | 24. south | 25. smsa66 
% | 26. wage | 27. enroll | 28. KWW | 29. IQ | 30. married 
% | 31. libcrd14 | 32. exper | % 33. lwage | 34. expersq

raw_data = csvread('data.csv');

raw_data_labels=['id      ';'nearc2  ';'nearc4  '; 'educ    ';'age     ';
    'fatheduc';'motheduc';'weight  ';'momdad14';'sinmom14';
    'step14  ';'reg661  ';'reg662  ';'reg663  ';'reg664  ';
    'reg665  ';'reg666  ';'reg667  ';'reg668  ';'reg669  ';
    'south66 ';'black   ';'smsa    ';'south   ';'smsa66  ';
    'wage    ';'enroll  ';'KWW     ';'IQ      ';'married ';
    'libcrd14';'exper   ';'lwage   ';'expersq '];

raw_x=zeros(num_raw_obs,length_raw_x);
raw_x_labels_index=zeros(1,length_raw_x);
raw_lwage_label_index=33;
raw_iq_label_index=29;
raw_kww_label_index=28;

%% parse raw_x
parse_iv_raw_data;

 for iv_outcome=1:6
   
    if iv_outcome>3
        % this alters the raw_z variable from nearc4 to living near 4-year college multiplied by low parental education
        for raw_count=1:num_raw_obs
            if raw_data(raw_count,6)>=12 || raw_data(raw_count,7)>=12 % parents' education is considered low when both are below 12
                raw_z(raw_count,1)=0;
            end
        end
   end
    
    generate_iv_titles;
    fprintf(1,'===================================================================================\n');
    fprintf(1,'Case %d: %s\n',iv_outcome,case_title);
    fprintf(1,'Summary: %s\n', case_summary);
    fprintf(1,'===================================================================================\n');
   
    %% populate num_valid_obs and variables
    populate_iv_data;
    
    %% run iv analysis on each case of iv outcome
    run_iv_analysis;
end;

for iv_outcome=13:14
   
    if iv_outcome==14
        % this alters the raw_cause_z variable from nearc4 to living near 4-year college multiplied by low parental education
        for raw_count=1:num_raw_obs
            if raw_data(raw_count,6)>=12 || raw_data(raw_count,7)>=12 % parent's education is considered low when both are below 12
                raw_z(raw_count,1)=0;
            end
        end
   end
    
    generate_iv_titles;
    fprintf(1,'===================================================================================\n');
    fprintf(1,'Case %d: %s\n',iv_outcome,case_title);
    fprintf(1,'Summary: %s\n', case_summary);
    fprintf(1,'===================================================================================\n');
   
    %% populate length_x, num_valid_obs
    populate_iv_data;
    
    %% run ivpp analysis on each case of ivpp outcome
    run_iv_analysis;
end;
    