clear all;
clc;

%% ask what significance level to use
global input_alpha
input_alpha = input('Which significance level do you want to use (alpha)? [default=0.05] ');
if isempty(input_alpha)
    input_alpha = 0.05;
end;

length_raw_x= 20; % number of raw cause x
num_raw_obs=3010; % number of raw observations

%% retrive data from CSV file and populate the following variables
% data.csv: -1 means that particular data is missing
% data.csv has data in the following order
% 1. id | 2. nearc2 | 3. nearc4 | 4. educ | 5. age |
% 6. fatheduc | 7. motheduc | 8. weight | 9. momdad14 | 10. sinmom14 | 
% 11. step14 | 12. reg661 | 13. reg662 | 14. reg663 | 15. reg664 | 
% 16. reg665 | 17 reg666 | 18. reg667 | 19. reg668 | 20. reg669 | 
% 21. south66 | 22. black | 23. smsa | 24. south | 25. smsa66 | 
% 26. wage | 27. enroll | 28. KWW | 29. IQ | 30. married | 
% 31. libcrd14 | 32. exper | 33. lwage | 34. expersq

raw_data = csvread('data.csv');

raw_data_labels=['id      ';'nearc2  ';'nearc4  '; 'educ    ';'age     ';
    'fatheduc';'motheduc';'weight  ';'momdad14';'sinmom14';
    'step14  ';'reg661  ';'reg662  ';'reg663  ';'reg664  ';
    'reg665  ';'reg666  ';'reg667  ';'reg668  ';'reg669  ';
    'south66 ';'black   ';'smsa    ';'south   ';'smsa66  ';
    'wage    ';'enroll  ';'KWW     ';'IQ      ';'married ';
    'libcrd14';'exper   ';'lwage   ';'expersq '];

raw_x=zeros(num_raw_obs,length_raw_x);
raw_labels_index=zeros(1,length_raw_x);
raw_lwage_label_index=33;
raw_iq_label_index=29;
raw_kww_label_index=28;

%% parse raw_x
parse_raw_data;

% Create values to be graphed
edu_ind_estimates=zeros(2,17);
edu_lower_bound=zeros(2,17);
edu_upper_bound=zeros(2,17);
edu_lower_cis=zeros(2,17);
edu_upper_cis=zeros(2,17);
mag_edu_lower_bound=zeros(2,17);
mag_edu_upper_bound=zeros(2,17);
mag_edu_lower_cis=zeros(2,17);
mag_edu_upper_cis=zeros(2,17);
edu_ind_pp_estimates= zeros(1,17);
close all;


%This generates the prefect proxy estimates used in drawing the last graph in draw_graphs; 
populate_case25;
x_tilde=zeros(num_valid_obs,length_x);
    
for xcount=1:length_x
        x_tilde(:,xcount)=x(:,xcount)-mean(x(:,xcount));
end
y_tilde=y-mean(y);
R_y_x_tilde=simple_regression(y_tilde, x_tilde);
    
edu_ind_pp_estimates(1:17)= R_y_x_tilde(1:17);


for outcome=13:18
    generate_titles;
    fprintf(1,'===================================================================================\n');        
    fprintf(1,'Case %d: %s\n',outcome,case_title);
    fprintf(1,'Summary: %s\n', case_summary);
    fprintf(1,'===================================================================================');        
    %% populate num_valid_obs and variables
    populate_data;
    
    %% run analysis on each of the relevant outcomes
    run_analysis;
    
    %% Draw Graphs
    draw_graphs;
end;


for outcome=24:25
    generate_titles;
    fprintf(1,'===================================================================================\n');        
    fprintf(1,'Case %d: %s\n',outcome,case_title);
    fprintf(1,'Summary: %s\n', case_summary);
    fprintf(1,'===================================================================================');        
    %% populate length_x,num_valid_obs
    populate_data;
    
    %% run analysis on each of the relevant outcomes
    run_analysis;
   
end;




